/*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 1, or (at your option)
* any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
* 
* AUTHOR: Angelo Rosiello
* CONTACT: angelo@rosiello.org, rosiello.angelo@virgilio.it, angelo@dtors.net               
*/


#include "environment/issue.h"
#include "search/search.h"
#include "interaction/interactive.h"

main(int argc, char *argv[])
{
	char *distro;
	char *host = "fr.rpmfind.net";
	char *ip;
	char *url;
	char *package;
	char *command_line;
	char *command;
	char *time;
	char *argument;
	char *string_help 	= "help";
	char *find		= "find";
	char *get 		= "get";
	char *string_install   	= "install";
	char *string_upgrade	= "upgrade";
	char *string_remove	= "remove";
	
	struct hostent *he;
	int status, status_install, first_time;

	first_time = 1;
	
	if(argc == 1)
	{
        	if ((he = gethostbyname(host)) == NULL)
        	{
                	fprintf(stderr, "(rpf) Hostname lookup failed!\n");
                	exit(1);
        	}
        }
        
        else if(argc == 2 || argc > 3)
        {
        		printf("\nUSAGE: %s\n", argv[0]);
   			printf("or\n");
        		printf("USAGE: %s -h host (Get hosts from README)\n", argv[0]);
        		exit(0);
        }
        
        else if(argc == 3)
        {
        	if(!strcmp(argv[1], "-h"))
        	{
        		if ((he = gethostbyname(argv[2])) == NULL)
        		{
                		fprintf(stderr, "(rpf) Hostname lookup failed!\n");
                		exit(1);
        		}
        	}
        	
        	else
        	{
         		printf("\nUSAGE: %s\n", argv[0]);
        		printf("or\n");
        		printf("USAGE: %s -h host (Get hosts from README)\n", argv[0]);
        		exit(0);
        	}	
        }

	ip = (char *)inet_ntoa(*((struct in_addr *)he->h_addr));


   	distro = (char *)check_version();							// Get The Distro
	
	// If The Automatic Checking Failed
	// Interaction with the user
	if(!os_known(distro))
	{
		printf("Sorry I couldn't detect your distro, introduce it now please\n");
		printf("e.g. Red Hat 7.3 = Red7.3\n");
		scanf("%s", distro);	
		if(os_known(distro)) printf("(rpf) Ok, We are on %s, Let's go on...\n", distro);
		else if(!os_known(distro))
		{
			printf("I'm desolated, your distro is not supported\n");
			printf("Contact Developers => http://www.rosiello.org\n");
			exit(0);
		}
	} 
	// end of interaction with user


	printf("(rpf) Welcome in the RPF version 1.2.1\n");
       	printf("(rpf) AUTHOR : Angelo Rosiello\n");
	printf("(rpf) CONTACT: angelo@rosiello.org\n");
	printf("(rpf) URL    : http://www.rosiello.org\n");
	
	while(1)
	{
		if(first_time)
		{	
			url = (char *)search(distro);
			time = web(url, ip);
			first_time = 0;
		}
 		command_line = (char *)interactive();
 		command = (char *)first_string(command_line);
		
		argument = (char *)second_string(command_line);

		
		if(!strcmp(command, string_help))
		{	
			if(!strcmp(argument, "EMPTY")) help();
			else(command_help(argument)); 
		}
		
                if(!strcmp(argument, "EMPTY") && strcmp(command, string_help))
                {
 	        	printf("(rpf) Missing argument!\n");
	             	command_help(command);
                     	command = "EMPTY";
                }
	      

 		if(!strcmp(command, find))
		{
 			package = (char *)match(argument);
 			if(!strcmp(package, "stop")) printf("(rpf) Package %s Not Found!\n", argument);
 			if(!strcmp(package, "FOUND")) continue;
 		}
 
		if(!strcmp(command, get ))
		{
			if(!(status = download(url, argument, ip))) printf("(rpf) WGET WORKED CORRECTLY\n");
			else printf("(rpf) ALERT, SOME ERROR OCCURRED WITH WGET EXECUTION!!!\n");
		}

		if(!strcmp(command, string_install ))
		{
			status_install = install(argument);
			if(status_install == 0) printf("(rpf) RPM INSTALLED\n");
			else 
			{			
				printf("(rpf) ALERT, SOME ERROR OCCURRED WITH INSTALLATION EXECUTION!!!\n");
				printf("(rpf) NOTHING INSTALLED\n");
			}
		}

		if(!strcmp(command, string_upgrade ))
		{
			status_install = upgrade(argument);
			if(status_install == 0) printf("(rpf) RPM UPGRADED\n");
			else
                        {
                                printf("(rpf) ALERT, SOME ERROR OCCURRED WITH UPGRADE EXECUTION!!!\n");
                                printf("(rpf) NOTHING UPGRADED\n");
                        }

		}
		
		if(!strcmp(command, string_remove ))
		{
			status = erase(argument);
			if(status == 0) printf("(rpf) PACKAGE REMOVED\n");
			else
                        {
                                printf("(rpf) ALERT, SOME ERROR OCCURRED WITH REMOVE EXECUTION!!!\n");
                                printf("(rpf) NOTHING REMOVED\n");
                        }

		}
	}
}

